/*
 * Database record class for DMAP sharing
 *
 * Copyright (C) 2008 W. Michael Petullo <mike@flyn.org>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#include "test-dmap-db.h"

/* This test implementation of the DAAPDb interface allows for one
 * record.  Normally, one would befine some data structure to contain
 * multiple records.
 */
static DMAPRecord *record = NULL;

/* Can not share media file ID with album ID (i.e., 1). */
static guint id = 1000;

DMAPRecord *
test_dmap_db_lookup_by_id (DMAPDb *db, guint id)
{
	/* In reality, lookup the proper record and return it. */
	return record;
}

void
test_dmap_db_foreach	     (const DMAPDb *db,
			      void (*fn) (gpointer id,
			      		  DMAPRecord *record,
					  gpointer data),
			      gpointer data)
{
	/* In reality, pull each record from the db and execute fn on it. */
        fn (GUINT_TO_POINTER (id), record, data);
}

gint64
test_dmap_db_count (const DMAPDb *db)
{
	/* In reality, return the record count. */
	return 1;
}

static void
test_dmap_db_init (TestDMAPDb *db)
{
}

static void
test_dmap_db_class_init (TestDMAPDbClass *klass)
{
}

static void
test_dmap_db_interface_init (gpointer iface, gpointer data)
{
	DMAPDbInterface *dmap_db = iface;

	g_assert (G_TYPE_FROM_INTERFACE (dmap_db) == TYPE_DMAP_DB);

	dmap_db->lookup_by_id = test_dmap_db_lookup_by_id;
	dmap_db->foreach = test_dmap_db_foreach;
	dmap_db->count = test_dmap_db_count;
}

G_DEFINE_TYPE_WITH_CODE (TestDMAPDb, test_dmap_db, G_TYPE_OBJECT, 
			 G_IMPLEMENT_INTERFACE (TYPE_DMAP_DB,
					        test_dmap_db_interface_init))

TestDMAPDb *
test_dmap_db_new (DMAPRecord *r)
{
	TestDMAPDb *db;

	db = TEST_DMAP_DB (g_object_new (TYPE_TEST_DMAP_DB, NULL));

	record = r;

	return db;
}
